==> config-api-0.3.11-sources.jar: org/wildfly/swarm/config/messaging_activemq/JMSBridge.java <==
package org.wildfly.swarm.config.messaging_activemq;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Map;
/**
 * A JMS bridge instance.
 */
@ResourceType("jms-bridge")
public class JMSBridge<T extends JMSBridge> {

	private String key;
	private Boolean addMessageidInHeader;
	private String clientId;
	private Long failureRetryInterval;
	private Integer maxBatchSize;
	private Long maxBatchTime;
	private Integer maxRetries;
	private String module;
	private Boolean paused;
	private String qualityOfService;
	private String selector;
	private Boolean started;
	private String subscriptionName;
	private String sourceConnectionFactory;
	private Map sourceContext = new java.util.HashMap<String, Object>();
	private String sourceDestination;
	private String sourcePassword;
	private String sourceUser;
	private String targetConnectionFactory;
	private Map targetContext = new java.util.HashMap<String, Object>();
	private String targetDestination;
	private String targetPassword;
	private String targetUser;

	public JMSBridge(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * If true, then the original message's message ID will be appended in the message sent to the destination in the header AMQ_BRIDGE_MSG_ID_LIST. If the message is bridged more than once, each message ID will be appended.
	 */
	@ModelNodeBinding(detypedName = "add-messageID-in-header")
	public Boolean addMessageidInHeader() {
		return this.addMessageidInHeader;
	}

	/**
	 * If true, then the original message's message ID will be appended in the message sent to the destination in the header AMQ_BRIDGE_MSG_ID_LIST. If the message is bridged more than once, each message ID will be appended.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge addMessageidInHeader(Boolean value) {
		this.addMessageidInHeader = value;
		return (JMSBridge) this;
	}

	/**
	 * The JMS client ID to use when creating/looking up the subscription if it is durable and the source destination is a topic.
	 */
	@ModelNodeBinding(detypedName = "client-id")
	public String clientId() {
		return this.clientId;
	}

	/**
	 * The JMS client ID to use when creating/looking up the subscription if it is durable and the source destination is a topic.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge clientId(String value) {
		this.clientId = value;
		return (JMSBridge) this;
	}

	/**
	 * The amount of time in milliseconds to wait between trying to recreate connections to the source or target servers when the bridge has detected they have failed.
	 */
	@ModelNodeBinding(detypedName = "failure-retry-interval")
	public Long failureRetryInterval() {
		return this.failureRetryInterval;
	}

	/**
	 * The amount of time in milliseconds to wait between trying to recreate connections to the source or target servers when the bridge has detected they have failed.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge failureRetryInterval(Long value) {
		this.failureRetryInterval = value;
		return (JMSBridge) this;
	}

	/**
	 * The maximum number of messages to consume from the source destination before sending them in a batch to the target destination. Its value must >= 1.
	 */
	@ModelNodeBinding(detypedName = "max-batch-size")
	public Integer maxBatchSize() {
		return this.maxBatchSize;
	}

	/**
	 * The maximum number of messages to consume from the source destination before sending them in a batch to the target destination. Its value must >= 1.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge maxBatchSize(Integer value) {
		this.maxBatchSize = value;
		return (JMSBridge) this;
	}

	/**
	 * The maximum number of milliseconds to wait before sending a batch to target, even if the number of messages consumed has not reached max-batch-size. Its value must be -1 to represent 'wait forever', or >= 1 to specify an actual time.
	 */
	@ModelNodeBinding(detypedName = "max-batch-time")
	public Long maxBatchTime() {
		return this.maxBatchTime;
	}

	/**
	 * The maximum number of milliseconds to wait before sending a batch to target, even if the number of messages consumed has not reached max-batch-size. Its value must be -1 to represent 'wait forever', or >= 1 to specify an actual time.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge maxBatchTime(Long value) {
		this.maxBatchTime = value;
		return (JMSBridge) this;
	}

	/**
	 * The number of times to attempt to recreate connections to the source or target servers when the bridge has detected they have failed. The bridge will give up after trying this number of times. -1 represents 'try forever'.
	 */
	@ModelNodeBinding(detypedName = "max-retries")
	public Integer maxRetries() {
		return this.maxRetries;
	}

	/**
	 * The number of times to attempt to recreate connections to the source or target servers when the bridge has detected they have failed. The bridge will give up after trying this number of times. -1 represents 'try forever'.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge maxRetries(Integer value) {
		this.maxRetries = value;
		return (JMSBridge) this;
	}

	/**
	 * The name of AS7 module containing the resources required to lookup source and target JMS resources.
	 */
	@ModelNodeBinding(detypedName = "module")
	public String module() {
		return this.module;
	}

	/**
	 * The name of AS7 module containing the resources required to lookup source and target JMS resources.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge module(String value) {
		this.module = value;
		return (JMSBridge) this;
	}

	/**
	 * Whether the JMS bridge is paused.
	 */
	@ModelNodeBinding(detypedName = "paused")
	public Boolean paused() {
		return this.paused;
	}

	/**
	 * Whether the JMS bridge is paused.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge paused(Boolean value) {
		this.paused = value;
		return (JMSBridge) this;
	}

	/**
	 * The desired quality of service mode (AT_MOST_ONCE, DUPLICATES_OK or ONCE_AND_ONLY_ONCE).
	 */
	@ModelNodeBinding(detypedName = "quality-of-service")
	public String qualityOfService() {
		return this.qualityOfService;
	}

	/**
	 * The desired quality of service mode (AT_MOST_ONCE, DUPLICATES_OK or ONCE_AND_ONLY_ONCE).
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge qualityOfService(String value) {
		this.qualityOfService = value;
		return (JMSBridge) this;
	}

	/**
	 * A JMS selector expression used for consuming messages from the source destination. Only messages that match the selector expression will be bridged from the source to the target destination.
	 */
	@ModelNodeBinding(detypedName = "selector")
	public String selector() {
		return this.selector;
	}

	/**
	 * A JMS selector expression used for consuming messages from the source destination. Only messages that match the selector expression will be bridged from the source to the target destination.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge selector(String value) {
		this.selector = value;
		return (JMSBridge) this;
	}

	/**
	 * Whether the JMS bridge is started.
	 */
	@ModelNodeBinding(detypedName = "started")
	public Boolean started() {
		return this.started;
	}

	/**
	 * Whether the JMS bridge is started.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge started(Boolean value) {
		this.started = value;
		return (JMSBridge) this;
	}

	/**
	 * The name of the subscription if it is durable and the source destination is a topic.
	 */
	@ModelNodeBinding(detypedName = "subscription-name")
	public String subscriptionName() {
		return this.subscriptionName;
	}

	/**
	 * The name of the subscription if it is durable and the source destination is a topic.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge subscriptionName(String value) {
		this.subscriptionName = value;
		return (JMSBridge) this;
	}

	/**
	 * The name of the source connection factory to lookup on the source messaging server.
	 */
	@ModelNodeBinding(detypedName = "source-connection-factory")
	public String sourceConnectionFactory() {
		return this.sourceConnectionFactory;
	}

	/**
	 * The name of the source connection factory to lookup on the source messaging server.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge sourceConnectionFactory(String value) {
		this.sourceConnectionFactory = value;
		return (JMSBridge) this;
	}

	/**
	 * The properties used to configure the source JNDI initial context.
	 */
	@ModelNodeBinding(detypedName = "source-context")
	public Map sourceContext() {
		return this.sourceContext;
	}

	/**
	 * The properties used to configure the source JNDI initial context.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge sourceContext(Map value) {
		this.sourceContext = value;
		return (JMSBridge) this;
	}

	/**
	 * The properties used to configure the source JNDI initial context.
	 */
	public JMSBridge sourceContextEntry(String key, Object value) {
		this.sourceContext.put(key, value);
		return (JMSBridge) this;
	}

	/**
	 * The name of the source destination to lookup on the source messaging server.
	 */
	@ModelNodeBinding(detypedName = "source-destination")
	public String sourceDestination() {
		return this.sourceDestination;
	}

	/**
	 * The name of the source destination to lookup on the source messaging server.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge sourceDestination(String value) {
		this.sourceDestination = value;
		return (JMSBridge) this;
	}

	/**
	 * The password for creating the source connection.
	 */
	@ModelNodeBinding(detypedName = "source-password")
	public String sourcePassword() {
		return this.sourcePassword;
	}

	/**
	 * The password for creating the source connection.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge sourcePassword(String value) {
		this.sourcePassword = value;
		return (JMSBridge) this;
	}

	/**
	 * The name of the user for creating the source connection.
	 */
	@ModelNodeBinding(detypedName = "source-user")
	public String sourceUser() {
		return this.sourceUser;
	}

	/**
	 * The name of the user for creating the source connection.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge sourceUser(String value) {
		this.sourceUser = value;
		return (JMSBridge) this;
	}

	/**
	 * The name of the target connection factory to lookup on the target messaging server.
	 */
	@ModelNodeBinding(detypedName = "target-connection-factory")
	public String targetConnectionFactory() {
		return this.targetConnectionFactory;
	}

	/**
	 * The name of the target connection factory to lookup on the target messaging server.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge targetConnectionFactory(String value) {
		this.targetConnectionFactory = value;
		return (JMSBridge) this;
	}

	/**
	 * The properties used to configure the target JNDI initial context.
	 */
	@ModelNodeBinding(detypedName = "target-context")
	public Map targetContext() {
		return this.targetContext;
	}

	/**
	 * The properties used to configure the target JNDI initial context.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge targetContext(Map value) {
		this.targetContext = value;
		return (JMSBridge) this;
	}

	/**
	 * The properties used to configure the target JNDI initial context.
	 */
	public JMSBridge targetContextEntry(String key, Object value) {
		this.targetContext.put(key, value);
		return (JMSBridge) this;
	}

	/**
	 * The name of the target destination to lookup on the target messaging server.
	 */
	@ModelNodeBinding(detypedName = "target-destination")
	public String targetDestination() {
		return this.targetDestination;
	}

	/**
	 * The name of the target destination to lookup on the target messaging server.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge targetDestination(String value) {
		this.targetDestination = value;
		return (JMSBridge) this;
	}

	/**
	 * The password for creating the target connection.
	 */
	@ModelNodeBinding(detypedName = "target-password")
	public String targetPassword() {
		return this.targetPassword;
	}

	/**
	 * The password for creating the target connection.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge targetPassword(String value) {
		this.targetPassword = value;
		return (JMSBridge) this;
	}

	/**
	 * The name of the user for creating the target connection.
	 */
	@ModelNodeBinding(detypedName = "target-user")
	public String targetUser() {
		return this.targetUser;
	}

	/**
	 * The name of the user for creating the target connection.
	 */
	@SuppressWarnings("unchecked")
	public JMSBridge targetUser(String value) {
		this.targetUser = value;
		return (JMSBridge) this;
	}
}

==> config-api-0.3.12-sources.jar: org/wildfly/swarm/config/messaging_activemq/JMSBridge.java <==
package org.wildfly.swarm.config.messaging_activemq;

import org.wildfly.swarm.config.runtime.Implicit;
import org.wildfly.swarm.config.runtime.ResourceType;
import org.wildfly.swarm.config.runtime.ModelNodeBinding;
import java.util.Map;
/**
 * A JMS bridge instance.
 */
@ResourceType("jms-bridge")
public class JMSBridge<T extends JMSBridge> {

	private String key;
	private Boolean addMessageidInHeader;
	private String clientId;
	private Long failureRetryInterval;
	private Integer maxBatchSize;
	private Long maxBatchTime;
	private Integer maxRetries;
	private String module;
	private Boolean paused;
	private String qualityOfService;
	private String selector;
	private Boolean started;
	private String subscriptionName;
	private String sourceConnectionFactory;
	private Map sourceContext;
	private String sourceDestination;
	private String sourcePassword;
	private String sourceUser;
	private String targetConnectionFactory;
	private Map targetContext;
	private String targetDestination;
	private String targetPassword;
	private String targetUser;

	public JMSBridge(String key) {
		this.key = key;
	}

	public String getKey() {
		return this.key;
	}

	/**
	 * If true, then the original message's message ID will be appended in the message sent to the destination in the header AMQ_BRIDGE_MSG_ID_LIST. If the message is bridged more than once, each message ID will be appended.
	 */
	@ModelNodeBinding(detypedName = "add-messageID-in-header")
	public Boolean addMessageidInHeader() {
		return this.addMessageidInHeader;
	}

	/**
	 * If true, then the original message's message ID will be appended in the message sent to the destination in the header AMQ_BRIDGE_MSG_ID_LIST. If the message is bridged more than once, each message ID will be appended.
	 */
	@SuppressWarnings("unchecked")
	public T addMessageidInHeader(Boolean value) {
		this.addMessageidInHeader = value;
		return (T) this;
	}

	/**
	 * The JMS client ID to use when creating/looking up the subscription if it is durable and the source destination is a topic.
	 */
	@ModelNodeBinding(detypedName = "client-id")
	public String clientId() {
		return this.clientId;
	}

	/**
	 * The JMS client ID to use when creating/looking up the subscription if it is durable and the source destination is a topic.
	 */
	@SuppressWarnings("unchecked")
	public T clientId(String value) {
		this.clientId = value;
		return (T) this;
	}

	/**
	 * The amount of time in milliseconds to wait between trying to recreate connections to the source or target servers when the bridge has detected they have failed.
	 */
	@ModelNodeBinding(detypedName = "failure-retry-interval")
	public Long failureRetryInterval() {
		return this.failureRetryInterval;
	}

	/**
	 * The amount of time in milliseconds to wait between trying to recreate connections to the source or target servers when the bridge has detected they have failed.
	 */
	@SuppressWarnings("unchecked")
	public T failureRetryInterval(Long value) {
		this.failureRetryInterval = value;
		return (T) this;
	}

	/**
	 * The maximum number of messages to consume from the source destination before sending them in a batch to the target destination. Its value must >= 1.
	 */
	@ModelNodeBinding(detypedName = "max-batch-size")
	public Integer maxBatchSize() {
		return this.maxBatchSize;
	}

	/**
	 * The maximum number of messages to consume from the source destination before sending them in a batch to the target destination. Its value must >= 1.
	 */
	@SuppressWarnings("unchecked")
	public T maxBatchSize(Integer value) {
		this.maxBatchSize = value;
		return (T) this;
	}

	/**
	 * The maximum number of milliseconds to wait before sending a batch to target, even if the number of messages consumed has not reached max-batch-size. Its value must be -1 to represent 'wait forever', or >= 1 to specify an actual time.
	 */
	@ModelNodeBinding(detypedName = "max-batch-time")
	public Long maxBatchTime() {
		return this.maxBatchTime;
	}

	/**
	 * The maximum number of milliseconds to wait before sending a batch to target, even if the number of messages consumed has not reached max-batch-size. Its value must be -1 to represent 'wait forever', or >= 1 to specify an actual time.
	 */
	@SuppressWarnings("unchecked")
	public T maxBatchTime(Long value) {
		this.maxBatchTime = value;
		return (T) this;
	}

	/**
	 * The number of times to attempt to recreate connections to the source or target servers when the bridge has detected they have failed. The bridge will give up after trying this number of times. -1 represents 'try forever'.
	 */
	@ModelNodeBinding(detypedName = "max-retries")
	public Integer maxRetries() {
		return this.maxRetries;
	}

	/**
	 * The number of times to attempt to recreate connections to the source or target servers when the bridge has detected they have failed. The bridge will give up after trying this number of times. -1 represents 'try forever'.
	 */
	@SuppressWarnings("unchecked")
	public T maxRetries(Integer value) {
		this.maxRetries = value;
		return (T) this;
	}

	/**
	 * The name of AS7 module containing the resources required to lookup source and target JMS resources.
	 */
	@ModelNodeBinding(detypedName = "module")
	public String module() {
		return this.module;
	}

	/**
	 * The name of AS7 module containing the resources required to lookup source and target JMS resources.
	 */
	@SuppressWarnings("unchecked")
	public T module(String value) {
		this.module = value;
		return (T) this;
	}

	/**
	 * Whether the JMS bridge is paused.
	 */
	@ModelNodeBinding(detypedName = "paused")
	public Boolean paused() {
		return this.paused;
	}

	/**
	 * Whether the JMS bridge is paused.
	 */
	@SuppressWarnings("unchecked")
	public T paused(Boolean value) {
		this.paused = value;
		return (T) this;
	}

	/**
	 * The desired quality of service mode (AT_MOST_ONCE, DUPLICATES_OK or ONCE_AND_ONLY_ONCE).
	 */
	@ModelNodeBinding(detypedName = "quality-of-service")
	public String qualityOfService() {
		return this.qualityOfService;
	}

	/**
	 * The desired quality of service mode (AT_MOST_ONCE, DUPLICATES_OK or ONCE_AND_ONLY_ONCE).
	 */
	@SuppressWarnings("unchecked")
	public T qualityOfService(String value) {
		this.qualityOfService = value;
		return (T) this;
	}

	/**
	 * A JMS selector expression used for consuming messages from the source destination. Only messages that match the selector expression will be bridged from the source to the target destination.
	 */
	@ModelNodeBinding(detypedName = "selector")
	public String selector() {
		return this.selector;
	}

	/**
	 * A JMS selector expression used for consuming messages from the source destination. Only messages that match the selector expression will be bridged from the source to the target destination.
	 */
	@SuppressWarnings("unchecked")
	public T selector(String value) {
		this.selector = value;
		return (T) this;
	}

	/**
	 * Whether the JMS bridge is started.
	 */
	@ModelNodeBinding(detypedName = "started")
	public Boolean started() {
		return this.started;
	}

	/**
	 * Whether the JMS bridge is started.
	 */
	@SuppressWarnings("unchecked")
	public T started(Boolean value) {
		this.started = value;
		return (T) this;
	}

	/**
	 * The name of the subscription if it is durable and the source destination is a topic.
	 */
	@ModelNodeBinding(detypedName = "subscription-name")
	public String subscriptionName() {
		return this.subscriptionName;
	}

	/**
	 * The name of the subscription if it is durable and the source destination is a topic.
	 */
	@SuppressWarnings("unchecked")
	public T subscriptionName(String value) {
		this.subscriptionName = value;
		return (T) this;
	}

	/**
	 * The name of the source connection factory to lookup on the source messaging server.
	 */
	@ModelNodeBinding(detypedName = "source-connection-factory")
	public String sourceConnectionFactory() {
		return this.sourceConnectionFactory;
	}

	/**
	 * The name of the source connection factory to lookup on the source messaging server.
	 */
	@SuppressWarnings("unchecked")
	public T sourceConnectionFactory(String value) {
		this.sourceConnectionFactory = value;
		return (T) this;
	}

	/**
	 * The properties used to configure the source JNDI initial context.
	 */
	@ModelNodeBinding(detypedName = "source-context")
	public Map sourceContext() {
		return this.sourceContext;
	}

	/**
	 * The properties used to configure the source JNDI initial context.
	 */
	@SuppressWarnings("unchecked")
	public T sourceContext(Map value) {
		this.sourceContext = value;
		return (T) this;
	}

	/**
	 * The properties used to configure the source JNDI initial context.
	 */
	public T sourceContext(String key, Object value) {
		if (this.sourceContext == null) {
			this.sourceContext = new java.util.HashMap<>();
		}
		this.sourceContext.put(key, value);
		return (T) this;
	}

	/**
	 * The name of the source destination to lookup on the source messaging server.
	 */
	@ModelNodeBinding(detypedName = "source-destination")
	public String sourceDestination() {
		return this.sourceDestination;
	}

	/**
	 * The name of the source destination to lookup on the source messaging server.
	 */
	@SuppressWarnings("unchecked")
	public T sourceDestination(String value) {
		this.sourceDestination = value;
		return (T) this;
	}

	/**
	 * The password for creating the source connection.
	 */
	@ModelNodeBinding(detypedName = "source-password")
	public String sourcePassword() {
		return this.sourcePassword;
	}

	/**
	 * The password for creating the source connection.
	 */
	@SuppressWarnings("unchecked")
	public T sourcePassword(String value) {
		this.sourcePassword = value;
		return (T) this;
	}

	/**
	 * The name of the user for creating the source connection.
	 */
	@ModelNodeBinding(detypedName = "source-user")
	public String sourceUser() {
		return this.sourceUser;
	}

	/**
	 * The name of the user for creating the source connection.
	 */
	@SuppressWarnings("unchecked")
	public T sourceUser(String value) {
		this.sourceUser = value;
		return (T) this;
	}

	/**
	 * The name of the target connection factory to lookup on the target messaging server.
	 */
	@ModelNodeBinding(detypedName = "target-connection-factory")
	public String targetConnectionFactory() {
		return this.targetConnectionFactory;
	}

	/**
	 * The name of the target connection factory to lookup on the target messaging server.
	 */
	@SuppressWarnings("unchecked")
	public T targetConnectionFactory(String value) {
		this.targetConnectionFactory = value;
		return (T) this;
	}

	/**
	 * The properties used to configure the target JNDI initial context.
	 */
	@ModelNodeBinding(detypedName = "target-context")
	public Map targetContext() {
		return this.targetContext;
	}

	/**
	 * The properties used to configure the target JNDI initial context.
	 */
	@SuppressWarnings("unchecked")
	public T targetContext(Map value) {
		this.targetContext = value;
		return (T) this;
	}

	/**
	 * The properties used to configure the target JNDI initial context.
	 */
	public T targetContext(String key, Object value) {
		if (this.targetContext == null) {
			this.targetContext = new java.util.HashMap<>();
		}
		this.targetContext.put(key, value);
		return (T) this;
	}

	/**
	 * The name of the target destination to lookup on the target messaging server.
	 */
	@ModelNodeBinding(detypedName = "target-destination")
	public String targetDestination() {
		return this.targetDestination;
	}

	/**
	 * The name of the target destination to lookup on the target messaging server.
	 */
	@SuppressWarnings("unchecked")
	public T targetDestination(String value) {
		this.targetDestination = value;
		return (T) this;
	}

	/**
	 * The password for creating the target connection.
	 */
	@ModelNodeBinding(detypedName = "target-password")
	public String targetPassword() {
		return this.targetPassword;
	}

	/**
	 * The password for creating the target connection.
	 */
	@SuppressWarnings("unchecked")
	public T targetPassword(String value) {
		this.targetPassword = value;
		return (T) this;
	}

	/**
	 * The name of the user for creating the target connection.
	 */
	@ModelNodeBinding(detypedName = "target-user")
	public String targetUser() {
		return this.targetUser;
	}

	/**
	 * The name of the user for creating the target connection.
	 */
	@SuppressWarnings("unchecked")
	public T targetUser(String value) {
		this.targetUser = value;
		return (T) this;
	}
}
